# Antidote — API JS-Connect v3

Antidote’s JavaScript-based API allows you to add Antidote’s three buttons (Corrector, Dictionaries and Guides) to an HTML page.

The buttons work the same way as when Antidote is run from the browser’s toolbar.

The API also allows users to link multiple editable fields to the corrector button so that only these fields will be processed by the corrector. It is also possible to insert multiple corrector buttons and to link each button to a group of fields to correct.

---

## Important

- See the file [index.html](index.html) for more details.

- Make sure that the Antidote connector is installed and that it has the API JS-Connect.
To do this:
        - Check for the presence of the antidoteapi_jsconnect_actif identifier.
                For example:
                var API_JS-Connect_EstPresent = document.getElementById('antidoteapi_jsconnect_actif') != null;

- The buttons cannot be selectable.

- The editable fields can only be linked to the corrector (and not to the dictionaries or guides).

- The API does not work with Internet Explorer.

---
## Activating the Buttons

Activating a button will trigger an API action when the button is clicked.

When the page is loaded, all the buttons are automatically activated. In order for automatic activation to take place, the ```<html>``` node needs to contain the attribute. 
        ```antidoteapi_jsconnect="true"```.

If a button is added after the page has loaded, it can be activated with the following call (it activates all the buttons that have yet to be activated):
        ```window.activeAntidoteAPI_JSConnect()```’

Buttons can be deactivated with the following call:
        ```window.desactiveAntidoteAPI_JSConnect();```

See [example of an activation](index.html#activation)

### Callback

If the page needs to trigger saving after a change, pass the callback function as a parameter :
	```window.activeAntidoteAPI_JSConnect(yourCallbackFunction);```

- Minimum version of the connectors
	- Firefox : 11.5.1937
	- Google Chrome : 11.5.1937
	- Safari : 11.5.1937

---
## Unlinked Buttons

To insert an unlinked button, add a node to the HTML code with the attribute data-antidoteapi_jsconnect_lanceoutil with one of the following parameters:
        "C" to launch the Corrector
        "D" to launch the Dictionaries
        "G" to launch the Guides
For example:
```
<button data-antidoteapi_jsconnect_lanceoutil="C">
```

See [example 1](index.html#example1)

---
## Button Linked to Editable Field

To insert a corrector button and to link it to a group of one field:

- Add the attribute `data-antidoteapi_jsconnect_groupe_id=PARAM` to the node of editable field you wish to link. `PARAM` identifies the field(s) to be linked.
For example:
```
	<textarea id="exemple2" data-antidoteapi_jsconnect_groupe_id="my_group_02">
```

- In addition to the attribute data-antidoteapi_jsconnect_lanceoutil (see Case 1), add the atribute `data-antidoteapi_jsconnect_groupe_id=PARAM` to the button’s node.
For example:
```
	<button data-antidoteapi_jsconnect_lanceoutil="C" data-antidoteapi_jsconnect_groupe_id="my_group_02">
```

See [example 2](index.html#example2)

---
## Button Linked to Editable Fields

To insert a corrector button and to link it to a group of one or more editable fields:

- Add the attribute `data-antidoteapi_jsconnect_groupe_id=PARAM` to the node of each editable field you wish to link. `PARAM` identifies the field(s) to be linked.
For example:
```
	<textarea id="exemple3_a" data-antidoteapi_jsconnect_groupe_id="my_group_03">
    <textarea id="exemple3_b" data-antidoteapi_jsconnect_groupe_id="my_group_03">
```

- In addition to the attribute data-antidoteapi_jsconnect_lanceoutil (see Case 1), add the atribute `data-antidoteapi_jsconnect_groupe_id=PARAM` to the button’s node.
For example:
```
	<button data-antidoteapi_jsconnect_lanceoutil="C" data-antidoteapi_jsconnect_groupe_id="my_group_03">
```
Note : le traitement de zones mixtes (noeud contenteditable=true + textarea), il faut avoir les connecteurs 11.0.12 et plus.

* See [example 3 (textarea)](index.html#example3)
* See [example 4 (div)](index.html#example4)
* See [example 5 (div + textarea)](index.html#example5)
* See [example 6 (iframe + textarea)](index.html#example6)

---
## Example of Implementation

1. Install the Antidote corrector in a Web browser (Firefox, Google Chrome, Safari).
2. Make sure that the Antidote connector offers the JS-Connect API (see above).
3. Copy the following files into a single folder on a web server:
        * index.html
        * antidote-api-js-connect-iframe.html
	* antidote-api-js-connect.js
	* antidote-api-js-connect.css
	* images/

4. Load the index.html page in the browser.

____________________________________
April 2025, © Druide informatique inc.
